"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
"""

from pathlib import Path

from nutrimatic.core.config import ensure_config
from nutrimatic.core.logger import setup_logging

cfg = ensure_config()  # loads singleton config
logger = setup_logging(cfg)  # loads singleton logger


def license_init(license_type: str) -> None:

    project_dir = Path.cwd()
    logger.info(f"{project_dir} {license_type}")

    # TODO: Remove NOTICE file if Apache-2.0 selected.



"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
"""

from typing import Any

from nutrimatic.core.config import ensure_config
from nutrimatic.core.logger import setup_logging

cfg = ensure_config()  # loads singleton config
logger = setup_logging(cfg)  # loads singleton logger


def get_make_cmds(context: dict[str, Any]) -> list[str]:
    """Generate one or more documentation templates inside docs/"""

    make_cfg = context.get("_hooks", {}).get("post_gen_make_cmds", {})

    all_make_cmds = [
        "python-install",
        "git-init",
        "pre-commit-init",
        "changelog",
        "build-docs",
    ]

    make_cmds = [cmd for cmd in all_make_cmds if make_cfg.get(cmd, False)]

    return make_cmds



"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
"""

from nutrimatic.core.config import ensure_config
from nutrimatic.core.logger import setup_logging
from nutrimatic.core.utils import make_dirs

cfg = ensure_config()  # loads singleton config
logger = setup_logging(cfg)  # loads singleton logger


def generate_cliff_changelog_dirs() -> None:
    """Generate changelog project directories"""
    changelog_dirs = [
        "changelogs",
        "changelogs/releases",
    ]
    make_dirs(changelog_dirs)



"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
"""

from nutrimatic.core.config import ensure_config
from nutrimatic.core.logger import setup_logging
from nutrimatic.core.utils import make_dirs

cfg = ensure_config()  # loads singleton config
logger = setup_logging(cfg)  # loads singleton logger


def generate_ansible_dirs() -> None:
    """Generate ansible project directories"""
    ansible_dirs = [
        "plugins",
        "plugins/action",
        "plugins/inventory",
        "plugins/lookup",
        "plugins/module_utils",
        "plugins/modules",
        "playbooks",
        "playbooks/files",
        "playbooks/tasks",
        "playbooks/templates",
        "playbooks/vars",
        "roles",
        "tests",
        "tests/units/",
        "tests/units/plugins",
        "tests/units/plugins/action",
        "tests/units/plugins/inventory",
        "tests/units/plugins/lookup",
        "tests/units/plugins/module_utils",
        "tests/units/plugins/modules",
        "tests/integration",
        "tests/integration/targets",
    ]
    make_dirs(ansible_dirs)
